Add a doc for contributor tips (#2480)

Contains some recommendations for tools and git setup for people
contributing to IREE. This is an opinionated guide that is largely just
*my* setup, but I know it overlaps significantly with other people's as
well and hopefully it can evolve into something more general.
diff --git a/scripts/git/bazel_to_cmake.sh b/scripts/git/bazel_to_cmake.sh
index 5b8234f..e5738fa 100755
--- a/scripts/git/bazel_to_cmake.sh
+++ b/scripts/git/bazel_to_cmake.sh
@@ -19,7 +19,7 @@
 #
 # - Requries the gh CLI (https://github.com/cli/cli) to create a PR.
 # - Will force push to the configured PR_BRANCH (default "bazel-to-cmake-fix")
 #   on the configured FORK_REMOTE (default "fork")
 # - Requires that local BASE_BRANCH branch is a pristine (potentially stale)
 #   copy of the same branch on the configured UPSTREAM_REMOTE
 #   (default "upstream").
@@ -32,7 +32,7 @@
 BASE_BRANCH="${1:-google}"
 PR_BRANCH="bazel-to-cmake-fix"
 UPSTREAM_REMOTE="${UPSTREAM_REMOTE:-upstream}"
-FORK_REMOTE="${FORK_REMOTE:-fork}"
+FORK_REMOTE="${FORK_REMOTE:-origin}"
 
 if [[ -n "$(git status --porcelain)" ]]; then
   echo "Working directory not clean. Aborting"
@@ -19,7 +19,7 @@
 # - Requries the gh CLI (https://github.com/cli/cli) to create a PR.
 # - Will force push to the configured PR_BRANCH (default "bazel-to-cmake-fix")
-#   on the configured FORK_REMOTE (default "fork")
+#   on the configured FORK_REMOTE (default "origin")
 # - Requires that local BASE_BRANCH branch is a pristine (potentially stale)
 #   copy of the same branch on the configured UPSTREAM_REMOTE